Learn R Programming

MARVEL (version 1.4.0)

adhocGene.DE.PSI.10x: Differential splice junction analysis of specified gene

Description

Performs differential splice junction analysis specified gene across for all possible pairs of cell groups. The gene and cell groups were defined earlier in adhocGene.TabulateExpression.Gene.10x function.

Usage

adhocGene.DE.PSI.10x(MarvelObject)

Value

An object of class S3 with new slots MarvelObject$adhocGene$DE$PSI$Data.

Arguments

MarvelObject

Marvel object. S3 object generated from adhocGene.TabulateExpression.PSI.10x function.

Examples

Run this code

marvel.demo.10x <- readRDS(system.file("extdata/data",
                               "marvel.demo.10x.rds",
                               package="MARVEL")
                               )

marvel.demo.10x <- adhocGene.DE.PSI.10x(MarvelObject=marvel.demo.10x)

# Check output
marvel.demo.10x$adhocGene$DE$PSI$Data

Run the code above in your browser using DataLab